package com.xy.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.xy.dto.FileExportDto;
import com.xy.entity.FileExport;
import com.xy.mapper.FileExportMapper;
import com.xy.utils.Emptys;
import com.xy.utils.MybatisPlusQuery;
import com.xy.utils.PageBean;
import com.xy.utils.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import java.util.List;

import static com.xy.utils.Beans.copy;
import static com.xy.utils.PlusBeans.toIPage;
import static com.xy.utils.PlusBeans.toPageBean;


/**
 * <p>
 * 文件导出 服务实现类
 * </p>
 *
 * @author 谭斌
 * @since 2023-03-04
 */
@Service
@RequiredArgsConstructor
@Api(tags = "文件导出")
public class FileExportServiceImpl extends ServiceImpl<FileExportMapper, FileExport> implements FileExportService {

    @Override
    @ApiOperation("对象查询")
    public R<FileExportDto.Vo> obj(FileExportDto.Vo vo) {
        FileExportDto.SelectList selectList = copy(FileExportDto.SelectList.class, vo);
        List<FileExportDto.Vo> list = list(selectList).getData();
        if (Emptys.check(list)) {
            return R.ok(list.get(0));
        }
        return R.ok();
    }

    @Override
    @ApiOperation("集合查询")
    public R<List<FileExportDto.Vo>> list(FileExportDto.SelectList selectList) {
        LambdaQueryWrapper<FileExport> lambdaQueryWrapper = new MybatisPlusQuery().eqWrapper(selectList, FileExport.class).build();
        List<FileExport> list = list(lambdaQueryWrapper);
        return R.ok(copy(FileExportDto.Vo.class, list));
    }

    @Override
    @ApiOperation("分页查询")
    public R<PageBean<FileExportDto.Vo>> page(FileExportDto.Page page) {
        PageBean pageBean = page.getPage();
        LambdaQueryWrapper<FileExport> lambdaQueryWrapper = new MybatisPlusQuery().eqWrapper(page, FileExport.class).build();
        IPage<FileExport> iPage = page(toIPage(pageBean), lambdaQueryWrapper);
        return R.ok(toPageBean(FileExportDto.Vo.class, iPage));
    }

    @Override
    @ApiOperation("添加")
    public R save(@Validated FileExportDto.Save save) {
        FileExport saveInfo = copy(FileExport.class, save);
        save(saveInfo);
        return R.ok();
    }

    @Override
    @ApiOperation("修改")
    public R update(@Validated FileExportDto.Update update) {
        FileExport updateInfo = copy(FileExport.class, update);
        updateById(updateInfo);
        return R.ok();
    }
}
